/*
 * Copyright (c) 2017. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.json;

import java.util.Date;

import com.google.gson.annotations.SerializedName;

import org.hedgecode.snooker.api.Player;

/**
 * Player Entity to JSON deserialize.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class JsonPlayer extends JsonIdEntity implements Player {

    @SerializedName("ID")
    private int playerId;
    @SerializedName("Type")
    private int type;
    @SerializedName("FirstName")
    private String firstName;
    @SerializedName("MiddleName")
    private String middleName;
    @SerializedName("LastName")
    private String lastName;
    @SerializedName("TeamName")
    private String teamName;
    @SerializedName("TeamNumber")
    private int teamNumber;
    @SerializedName("TeamSeason")
    private int teamSeason;
    @SerializedName("ShortName")
    private String shortName;
    @SerializedName("Nationality")
    private String nationality;
    @SerializedName("Sex")
    private String sex;
    @SerializedName("BioPage")
    private String bioPage;
    @SerializedName("Born")
    private Date born;
    @SerializedName("Twitter")
    private String twitter;
    @SerializedName("SurnameFirst")
    private boolean surnameFirst;
    @SerializedName("License")
    private String license;
    @SerializedName("Club")
    private String club;
    @SerializedName("URL")
    private String url;
    @SerializedName("Photo")
    private String photo;
    @SerializedName("Info")
    private String info;

    protected JsonPlayer() {
    }

    @Override
    public int playerId() {
        return playerId;
    }

    @Override
    public int type() {
        return type;
    }

    @Override
    public String firstName() {
        return firstName;
    }

    @Override
    public String middleName() {
        return middleName;
    }

    @Override
    public String lastName() {
        return lastName;
    }

    @Override
    public String teamName() {
        return teamName;
    }

    @Override
    public int teamNumber() {
        return teamNumber;
    }

    @Override
    public int teamSeason() {
        return teamSeason;
    }

    @Override
    public String shortName() {
        return shortName;
    }

    @Override
    public String nationality() {
        return nationality;
    }

    @Override
    public String sex() {
        return sex;
    }

    @Override
    public String bioPage() {
        return bioPage;
    }

    @Override
    public Date born() {
        return born == null
                ? null
                : new Date(born.getTime());
    }

    @Override
    public String twitter() {
        return twitter;
    }

    @Override
    public boolean surnameFirst() {
        return surnameFirst;
    }

    @Override
    public String license() {
        return license;
    }

    @Override
    public String club() {
        return club;
    }

    @Override
    public String url() {
        return url;
    }

    @Override
    public String photo() {
        return photo;
    }

    @Override
    public String info() {
        return info;
    }

    @Override
    public int getId() {
        return playerId;
    }

}
