/*
 * Copyright (c) 2017. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.snooker.json;

import java.util.ArrayList;
import java.util.List;

import org.hedgecode.snooker.api.Ranking;
import org.hedgecode.snooker.api.Rankings;
import org.hedgecode.snooker.compare.RankingComparators;

/**
 * Rankings Entity (set of {@link Ranking}) to JSON deserialize.
 *
 * @author Dmitry Samoshin aka gotty
 */
public class JsonRankings extends JsonCollectionEntity<Ranking> implements Rankings {

    private static final JsonRankings EMPTY = new JsonRankings(new Ranking[0]);

    protected JsonRankings(Ranking[] entities) {
        super(entities);
    }

    protected JsonRankings(List<Ranking> entities) {
        super(entities);
    }

    @Override
    public Ranking byPlayer(int playerId) {
        for (Ranking ranking : this)
            if (ranking.playerId() == playerId)
                return ranking;
        return null;
    }

    @Override
    public Rankings bySum(long minSum, long maxSum) {
        List<Ranking> rankings = new ArrayList<>();
        for (Ranking ranking : this)
            if (ranking.sum() >= minSum && ranking.sum() <= maxSum)
                rankings.add(ranking);
        return rankings.isEmpty() ? EMPTY : new JsonRankings(rankings);
    }

    @Override
    public void sortByPosition() {
        sort(
                RankingComparators.POSITION.comparator()
        );
    }

    @Override
    public void sortBySum() {
        sort(
                RankingComparators.SUM.comparator()
        );
    }

}
